@@ -13,5 +13,5 @@ def clean_text(text: str) -> str:
         str: [Cleaned text]
     """
     text = unidecode(text.lower())
-    text = re.sub('^[a-z0-9]+', ' ', text)
+    text = re.sub('[^a-z0-9]+', ' ', text)
     return text.strip()
\ No newline at end of file
